@@ -647,6 +647,8 @@ class LivejAccount(Account, Service):
 
         # parse result
         #convert text in our (HTML) format (\n to <br> )
+
+        
         event = self._parse_string(lj_post['event_raw'])
         event = event.replace('\n', '<br>')
         new_post.text = event
@@ -671,7 +673,8 @@ class LivejAccount(Account, Service):
             poster = Account.register(type(self), lj_post['postername'])
             poster.group = ('P' != lj_post['postertype'])
         new_post.poster = poster
-
+        new_post.url = "%s/%s.html" %(lj_post['journalurl'],str(lj_post['ditemid']))
+        print new_post.url
         new_post.custom_id = lj_post['ditemid']
 
         journal = self.find(LivejAccount,
@@ -739,6 +742,7 @@ class LivejAccount(Account, Service):
             param['skip'] = str(skip)
 
             result = self.exec_xmlrpc('getfriendspage', param)['entries']
+            
             callback()
 
             getted = len(result)
@@ -890,46 +894,51 @@ class LivejAccount(Account, Service):
         @param addit (Dict) unused
         @return None
         """
+	
         """
         def lookup_for_root(mesg):
             if mesg.type == POST:
                 return mesg
             else:
                 lookup_for_root(mesg.parent)
-          """
+        """
           
         req = None
         print "sending reach LiveJAccount"
-        try:
-            misc = parent.misc
-            if parent.type == POST:
-                ptid = 0
-                itemid = re.findall("\d+\.html$", parent.url)[0].split('.')[0]
-            else:
-                ptid = parent.custom_id
-                mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=? AND type=?",\
-                  (misc['parenttalkid'], self.id, POST))
-                print mid
-                itemid = re.findall("\d+\.html$", Message(mid).url)[0].split('.')[0]
-                #itemid = re.findall("\d+\.html$", lookup_for_root(Message(misc['parenttalkid'])).url)[0].split('.')[0]
-          
-            print "1"
-            req = {
-                'parenttalkid': ptid,
-                'itemid': itemid,
-                'journal': parent.journal.username,
-                'usertype': 'user',
-                'userpost': self.username,
-                'password': self.passwd,
-                'do_login': '1',
-                'subject': msg.title.encode( "utf-8" ),
-                'subjection':'none',
-                'body':msg.text.encode( "utf-8" ),
-            }
-            print "2"
-            req = urlencode(req)
-        except Exception, x:
-            print  x
+        #try:
+        misc = parent.misc
+        print "q"
+	if parent.type == POST:
+            print "e"
+            ptid = 0
+            print parent.url
+            itemid = re.findall("\d+\.html$", parent.url)[0].split('.')[0]
+        else:
+	    print "W"
+            ptid = parent.custom_id
+            mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=? AND type=?",\
+              (misc['parenttalkid'], parent.journal.id, POST))
+            print mid
+            itemid = re.findall("\d+\.html$", Message(mid).url)[0].split('.')[0]
+            #itemid = re.findall("\d+\.html$", lookup_for_root(Message(misc['parenttalkid'])).url)[0].split('.')[0]
+      
+        print "1"
+        req = {
+            'parenttalkid': ptid,
+            'itemid': itemid,
+            'journal': parent.journal.username,
+            'usertype': 'user',
+            'userpost': self.username,
+            'password': self.passwd,
+            'do_login': '1',
+            'subject': msg.title.encode( "utf-8" ),
+            'subjection':'none',
+            'body':msg.text.encode( "utf-8" ),
+        }
+        print "2"
+        req = urlencode(req)
+        #except Exception, x:
+        #    print  x
         print req
         try:
             resp = urllib2.urlopen(urllib2.Request(LJ_SHORT+"/talkpost_do.bml",req))
@@ -989,18 +998,22 @@ class LivejAccount(Account, Service):
         """
         session = self.get_session()
         misc = msg.misc
+        print msg.id
+        print misc
         if misc['frozen']:
-            mode = 'freeze'
-        else:
             mode = 'unfreeze'
+            if msg.have_frozen_parent():
+                raise WarningExc("LivejAccount", "Comment parent is frozen. Can't unfroze comment.")
+        else:
+            mode = 'freeze'
         #FIXME dirty hack!!!
-        req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
+        req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?confirm='Y'&mode=%s&journal=%s&talkid=%i" % (mode, msg.journal.username,\
                     int(str((int(msg.custom_id)) * 256 +5))),headers = {'Cookie': "ljsession=%s" %(session)})
         #FIXME end of dirty hack!!!
         r = urllib2.urlopen(req)
+        req.get_full_url()
         page = r.readlines()
         self.__confirm(page,session,None)
-        
         if misc['frozen']:
             msg.unfroze_childs()
         else:
@@ -1018,16 +1031,21 @@ class LivejAccount(Account, Service):
         """
         session = self.get_session()
         misc = msg.misc
+        print misc
         if misc['screened']:
-            mode = 'screen'
-        else:
             mode = 'unscreen'
+            if msg.have_screened_parent():
+                raise WarningExc("LivejAccount", "Comment parent is screened. Can't unscreen comment.")           
+        else:
+            mode = 'screen'
         #FIXME dirty hack!!!
-        req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
+        req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal.username,\
                     int(str((int(msg.custom_id)) * 256 +5))),headers = {'Cookie': "ljsession=%s" %(session)})
         #FIXME end of dirty hack!!!
+        print req.get_full_url()
         r = urllib2.urlopen(req)
         page = r.readlines()
+        
         self.__confirm(page,session,None)
         
         if misc['screened']:
@@ -1235,10 +1253,11 @@ class LivejAccount(Account, Service):
                 continue
                 #raise LookupError("Message not founded in DB", "Trying to screen not existing message")
             
-            misc = comment.misc
-            misc['screened'] = True
-            comment.misc = misc
+            #misc = comment.misc
+            #misc['screened'] = True
+            #comment.misc = misc
             #TODO: add to message class
+            #NOTE: screening is independent for parent and childs
             comment.screen_childs()
             self.add_marked(comment,'screened')
             
@@ -1280,27 +1299,37 @@ class LivejAccount(Account, Service):
         pat = ("<!-- your content here -->","<!-- Content -->")
         while not strsinstr(page.pop(0), pat):
             pass
+        if len(page)==0:
+            raise WarningExc("LivejAccount", "Illegel response from Service")
 
         pat = ("<!-- /content -->","<!-- End \#content -->")
         while not strsinstr(page.pop(), pat):
             pass
-          
+        if len(page)==0:
+            raise WarningExc("LivejAccount", "Illegel response from Service")
+        
         #Look for form in HTML-page
         html_data = string.join(page)
+        print html_data
         parcer = CHTMLParser()
         parcer.feed(html_data)
         #Update params by user's params
+        
         params = parcer.params
         if uparams:
             params.update(uparams)
+        try:
+            del params['']
+        except:
+            pass
+        print params
+        if not parcer.request:
+            raise WarningExc("LivejAccount", "Illegel response from Service")
+
         #send request
-        print "============================="
-        print parcer.request
-        print urllib.urlencode(params)
-        print headers
-        print "============================="
         req=urllib2.Request(parcer.request, urllib.urlencode(params), headers=headers)
-        print req
+        print headers
+        print req.get_full_url()
         r = urllib2.urlopen(req)
 
     """
