@@ -9,6 +9,7 @@ Class with test method for Message module
 
 from services.Dispatcher import dispatcher
 from ldm.Message import Message
+from ldm.Account import Account
 from FakeAccount import FakeAccount
 from ScriboExc import WarningExc
 import unittest
@@ -178,7 +179,7 @@ class MessageTest(unittest.TestCase):
         some comments as read/unread 
         """
 
-        acc = FakeAccount()
+        acc = Account.register(FakeAccount,"asjaisj")
         acc.add_post(self.msg)
         self.assertFalse(len(self.msg.comments))
         for _ in xrange(5):
@@ -236,7 +237,7 @@ class MessageTest(unittest.TestCase):
         try to assign diffrent values: correct and not corrent 
         """
 
-        acc = FakeAccount()
+        acc = Account.register(FakeAccount,"asjaisj")
         self.msg.poster = acc
         self.assertEqual(acc, self.msg.poster)
 
@@ -253,7 +254,7 @@ class MessageTest(unittest.TestCase):
         try to assign diffrent values: correct and not corrent
         """
 
-        acc = FakeAccount()
+        acc = Account.register(FakeAccount,"asjaisj")
         self.msg.journal = acc
         self.assertEqual(acc, self.msg.journal)
 
