@@ -14,6 +14,9 @@ __license__ = "GPLv2"
 
 import unittest
 
+import sys
+sys.path.append("..")
+
 from LdmTest import LdmTest                 #IGNORE:W0611
 from ProfileTest import ProfileTest         #IGNORE:W0611
 from SqlDriverTest import SqlDriverTest     #IGNORE:W0611
