@@ -8,20 +8,13 @@
   @date: 14.02.2010
 """
 
-import sys
-"""
-sys.path.append("..")
-sys.path.append("../ldm")
-sys.path.append("../ui")
-sys.path.append("../services")
-"""
+
 from ldm.Message import Message
-from ldm.Profile import *
-from ldm.Account import *
-from services.LivejAccount import *
-from services.BlurtyAccount import *
-from time import *
-import random
+from ldm.Profile import main_prof
+from ldm.Account import Account
+from services.Dispatcher import dispatcher
+#from time import time, localtime
+#import random
 
 
 
@@ -44,8 +37,8 @@ class SysBugs:
         initialization of test account
         @return
         """
-        acc = LivejAccount()
-        acc.username = "scribo_rpc"
+        service = dispatcher.get_services()[0]
+        acc = Account.register(service, "scribo_rpc")
         acc.passwd = "test123"
 
         try:
@@ -63,8 +56,8 @@ class SysBugs:
         duble of added acounts 
         """
 
-        acc = LivejAccount()
-        acc.username = "maemoblogs"
+        service = dispatcher.get_services()[0]
+        acc = Account.register(service, "maemoblogs")
         acc.passwd = "maemo100500"
 
         try:
@@ -94,6 +87,7 @@ class SysBugs:
         try:
             main_prof.def_account.add_post(mes)
             res = main_prof.def_account.send_post(mes)
+            print res
         except:
             print "ERROR!!!1"
         else:
@@ -108,12 +102,13 @@ class SysBugs:
         mes.text = unicode("Hello, moonSpIRiT")
         main_prof.def_account.add_post(mes)
         res = main_prof.def_account.send_post(mes)
-
+        print res
 
         print "\nbug 87: "
         try:
             main_prof.def_account.refresh_posts(self.callback)
-            list = main_prof.get_posts()
+            list1 = main_prof.get_posts()
+            print list1
         except:
             print 'ERROR'
         else:
@@ -127,9 +122,11 @@ class SysBugs:
         print "\nbug 78: "
         try:
             main_prof.def_account.refresh_posts(self.callback)
-            list = main_prof.get_posts()
+            list1 = main_prof.get_posts()
+            print list1
             main_prof.def_account.refresh_posts(self.callback)
-            list = main_prof.get_posts()
+            list1 = main_prof.get_posts()
+            print list1
         except:
             print 'ERROR'
         else:
@@ -140,8 +137,8 @@ class SysBugs:
         """
         BD fail after second posts refresh
         """
-        acc = BlurtyAccount()
-        acc.username = "sscribo"
+        service = dispatcher.get_services()[1]
+        acc = Account.register(service, "sscribo")
         acc.passwd = "test123"
         try:
             main_prof.add_account(acc)
@@ -158,16 +155,18 @@ class SysBugs:
         try:
             main_prof.def_account.add_post(mes)
             res = main_prof.def_account.send_post(mes)
+            print res
         except:
             print 'ERROR'
         else:
             print 'fixed'
 
-        acca = LivejAccount()
-        acca.username = "scribo_rpc"
-        same_acc = Account.find(type(acca), acca.username)
+        accs = main_prof.get_accounts()
 
-        main_prof.set_def_account(same_acc)
+        for acc in accs:
+            if(acc.username == "scribo_rpc"):
+                if(acc.service_id == "LivejAccount"):
+                    main_prof.set_def_account(acc)
 
 
     def bug214(self):
@@ -182,6 +181,7 @@ class SysBugs:
         try:
             main_prof.def_account.add_post(mes)
             res = main_prof.def_account.send_post(mes)
+            print res
         except:
             print 'ERROR'
         else:
@@ -201,6 +201,7 @@ class SysBugs:
         try:
             main_prof.def_account.add_post(mes)
             res = main_prof.def_account.send_post(mes)
+            print res
         except:
             if (mes.text == ""):
                 print 'fixed'
@@ -236,7 +237,8 @@ class SysBugs:
         print "\ngetting those posts"
         try:
             main_prof.def_account.refresh_posts(self.callback)
-            list = main_prof.get_posts()
+            list1 = main_prof.get_posts()
+            print list1
         except:
             print 'ERROR'
         else:
