@@ -146,7 +146,7 @@ class AddPostWindow(MainWindow):
         """
 
         self.pict_act = QtGui.QToolButton(self.centr_widg)
-        self.pict_act.setIcon(QtGui.QIcon(self.tr("../data/en/image.png")))
+        self.pict_act.setIcon(QtGui.QIcon("../data/en/image.png"))
         self.pict_act.setText(self.tr("Add image"))
         self.pict_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.pict_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -154,7 +154,7 @@ class AddPostWindow(MainWindow):
                      self.pict_post)
 
         self.other_act = QtGui.QToolButton(self.centr_widg)
-        self.other_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_html.png")))
+        self.other_act.setIcon(QtGui.QIcon("../data/en/add_html.png"))
         self.other_act.setText(self.tr("HTML"))
         self.other_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.other_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -162,7 +162,7 @@ class AddPostWindow(MainWindow):
                      self.other_post)
 
         self.option_act = QtGui.QToolButton(self.centr_widg)
-        self.option_act.setIcon(QtGui.QIcon(self.tr("../data/en/options.png")))
+        self.option_act.setIcon(QtGui.QIcon("../data/en/options.png"))
         self.option_act.setText(self.tr("Options"))
         self.option_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.option_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -170,7 +170,7 @@ class AddPostWindow(MainWindow):
                      self.option_post)
         
         self.save_act = QtGui.QToolButton(self.centr_widg)
-        self.save_act.setIcon(QtGui.QIcon(self.tr("../data/en/save.png")))
+        self.save_act.setIcon(QtGui.QIcon("../data/en/save.png"))
         self.save_act.setText(self.tr("Save"))
         self.save_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.save_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -179,7 +179,7 @@ class AddPostWindow(MainWindow):
 
 
         self.undo_act = QtGui.QToolButton(self.centr_widg)
-        self.undo_act.setIcon(QtGui.QIcon(self.tr("../data/en/undo.png")))
+        self.undo_act.setIcon(QtGui.QIcon("../data/en/undo.png"))
         self.undo_act.setText(self.tr("Undo"))
         self.undo_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.undo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -187,7 +187,7 @@ class AddPostWindow(MainWindow):
                      self.text_edit.undo)
 
         self.redo_act = QtGui.QToolButton(self.centr_widg)
-        self.redo_act.setIcon(QtGui.QIcon(self.tr("../data/en/redo.png")))
+        self.redo_act.setIcon(QtGui.QIcon("../data/en/redo.png"))
         self.redo_act.setText(self.tr("Redo"))
         self.redo_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.redo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -196,12 +196,12 @@ class AddPostWindow(MainWindow):
     
         self.send_act = QtGui.QToolButton(self)
         if not self.msg or not self.msg.poster:
-            self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_send_to.png")))
+            self.send_act.setIcon(QtGui.QIcon("../data/en/post_send_to.png"))
             self.send_act.setText(self.tr("Send to.."))
             self.connect(self.send_act, QtCore.SIGNAL("clicked()"),
                          self.send_post)
         else:
-            self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/send_post.png")))
+            self.send_act.setIcon(QtGui.QIcon("../data/en/send_post.png"))
             self.send_act.setText(self.tr("Send"))
             self.connect(self.send_act, QtCore.SIGNAL("clicked()"),
                          self.edit_post)
