@@ -113,7 +113,7 @@ class ListFriends(MainWindow):
         @return
         """
         self.refresh_act = QtGui.QToolButton(self.centr_widg)
-        self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
+        self.refresh_act.setIcon(QtGui.QIcon("../data/en/refresh.png"))
         self.refresh_act.setText(self.tr("Refresh"))
         self.refresh_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -122,7 +122,7 @@ class ListFriends(MainWindow):
                      self.reload_window)
 
         self.del_act = QtGui.QToolButton(self.centr_widg)
-        self.del_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_delete.png")))
+        self.del_act.setIcon(QtGui.QIcon("../data/en/post_delete.png"))
         self.del_act.setText(self.tr("Delete"))
         self.del_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
