@@ -59,16 +59,16 @@ class ListMyPosts(MainWindow):
         self.mes_list = self.list_posts(friend)
         
         #widget's for sorting
-        label_sort = QtGui.QLabel(self.tr("Sort by:"))
+        label_sort = QtGui.QLabel(QtCore.QCoreApplication.translate("ListMyPosts","Sort by:"))
         button_asc = QtGui.QPushButton()
         button_desc = QtGui.QPushButton()
-        button_asc.setIcon(QtGui.QIcon(self.tr("../data/en/sort_asc.png")))
-        button_desc.setIcon(QtGui.QIcon(self.tr("../data/en/sort_desc.png")))    
+        button_asc.setIcon(QtGui.QIcon("../data/en/sort_asc.png"))
+        button_desc.setIcon(QtGui.QIcon("../data/en/sort_desc.png"))    
        
         self.combo_sort = QtGui.QComboBox()
-        self.combo_sort.addItem(self.tr("On date"))
-        self.combo_sort.addItem(self.tr("On title"))     
-        self.combo_sort.addItem(self.tr("On read/unread"))
+        self.combo_sort.addItem(QtCore.QCoreApplication.translate("ListMyPosts","On date"))
+        self.combo_sort.addItem(QtCore.QCoreApplication.translate("ListMyPosts","On title"))     
+        self.combo_sort.addItem(QtCore.QCoreApplication.translate("ListMyPosts","On read/unread"))
 
         self.hbox_sort.addWidget(label_sort)
         self.hbox_sort.addWidget(self.combo_sort, 2,QtCore.Qt.AlignVCenter)
@@ -97,8 +97,8 @@ class ListMyPosts(MainWindow):
         @return                                                                                                                                             
         """
         super(ListMyPosts,self).create_menus()
-        self.filter_act = QtGui.QAction(self.tr("Filters"), self)
-        self.filter_act.setShortcut(self.tr("Ctrl+N"))
+        self.filter_act = QtGui.QAction(QtCore.QCoreApplication.translate("ListMyPosts","Filters"), self)
+        self.filter_act.setShortcut(QtCore.QCoreApplication.translate("ListMyPosts","Ctrl+N"))
         self.connect(self.filter_act, QtCore.SIGNAL("triggered()"),
                                   self.filter_mes_box)
         self.main_menu.addAction(self.filter_act)
@@ -120,9 +120,9 @@ class ListMyPosts(MainWindow):
             c = config.get_bool('UI', 'warning_press_refresh')
             if not c:
                 msg = QtGui.QMessageBox()
-                msg.setWindowTitle(self.tr("Refresh message"))
-                show_button = QtGui.QCheckBox(self.tr("Don't show this message again"), msg)
-                title_label = QtGui.QLabel(self.tr("Press \"Refresh\" to update post"), msg)
+                msg.setWindowTitle(QtCore.QCoreApplication.translate("ListMyPosts","Refresh message"))
+                show_button = QtGui.QCheckBox(QtCore.QCoreApplication.translate("ListMyPosts","Don't show this message again"), msg)
+                title_label = QtGui.QLabel(QtCore.QCoreApplication.translate("ListMyPosts","Press \"Refresh\" to update post"), msg)
                 msg.layout().addWidget(title_label, 0, 0)
                 msg.layout().addWidget(show_button, 1, 0)
                 cancel_button = msg.addButton(QtGui.QMessageBox.Close)
@@ -141,7 +141,7 @@ class ListMyPosts(MainWindow):
             date = time.strftime("%a, %d %b %Y %H:%M", datetime)
             """
             if not mes.title:
-                title = unicode(self.tr("no subject"))
+                title = unicode(QtCore.QCoreApplication.translate("ListMyPosts","no subject"))
             else:
                 title = unicode(mes.title)
             #text = date.decode('utf8') + "  " + title
@@ -190,8 +190,8 @@ class ListMyPosts(MainWindow):
         @return
         """
         self.refresh_act = QtGui.QToolButton(self.centr_widg)
-        self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
-        self.refresh_act.setText(self.tr("Refresh"))
+        self.refresh_act.setIcon(QtGui.QIcon("../data/en/refresh.png"))
+        self.refresh_act.setText(QtCore.QCoreApplication.translate("ListMyPosts","Refresh"))
         self.refresh_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
 
@@ -199,8 +199,8 @@ class ListMyPosts(MainWindow):
                      self.reload_window)
 
         self.del_act = QtGui.QToolButton(self.centr_widg)
-        self.del_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_delete.png")))
-        self.del_act.setText(self.tr("Delete"))
+        self.del_act.setIcon(QtGui.QIcon("../data/en/post_delete.png"))
+        self.del_act.setText(QtCore.QCoreApplication.translate("ListMyPosts","Delete"))
         self.del_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.del_act, QtCore.SIGNAL("clicked()"),
@@ -214,8 +214,14 @@ class ListMyPosts(MainWindow):
         @return       
         """
         index = item.data(QtCore.Qt.UserRole).toString().toInt()[0]
+        if self.flag_is_filter or self.flag_is_sort:
+            self.list = self.filter_list
         mes = self.list[index]
-        view_widg = ViewMessage(self, self.get_messages(self.friend), mes)
+        item.setTextColor(QtCore.Qt.white)
+        if not self.flag_is_filter and not self.flag_is_sort:
+            view_widg = ViewMessage(self, self.get_messages(self.friend), mes)
+        else:
+            view_widg = ViewMessage(self, self.filter_list, mes)
         
 
     def delete_message(self):
@@ -224,12 +230,14 @@ class ListMyPosts(MainWindow):
         @param
         @return       
         """
-        ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Do you really want to delete post?"),
+        ret = QtGui.QMessageBox.information(self, QtCore.QCoreApplication.translate("ListMyPosts","Scribo"),
+                               QtCore.QCoreApplication.translate("ListMyPosts","Do you really want to delete post?"),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
         if (ret == QtGui.QMessageBox.No):
             return
+        if self.flag_is_filter or self.flag_is_sort:
+            self.list = self.filter_list
         list = self.mes_list.selectedItems()
         if list:
             for item in list:
@@ -252,8 +260,8 @@ class ListMyPosts(MainWindow):
                     item.setSelected(False)
 
         else:
-            QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Please, choose messages to delete!"),
+            QtGui.QMessageBox.information(self, QtCore.QCoreApplication.translate("ListMyPosts","Scribo"),
+                               QtCore.QCoreApplication.translate("ListMyPosts","Please, choose messages to delete!"),
                                QtGui.QMessageBox.Yes)
 
     def reload_window(self):
@@ -303,7 +311,8 @@ class ListMyPosts(MainWindow):
                     acc.refresh_friends_page(self.callback)
                 except WarningExc, exc:
                     main_window.show_warning(exc)
-
+        self.flag_is_filter = False
+        self.flag_is_sort = False
 
 
 
@@ -331,23 +340,23 @@ class ListMyPosts(MainWindow):
         but_box = QtGui.QDialogButtonBox()
         but_box.setOrientation(QtCore.Qt.Vertical)
 
-        self.f_dial.setWindowTitle(self.tr("Filters"))
+        self.f_dial.setWindowTitle(QtCore.QCoreApplication.translate("ListMyPosts","Filters"))
         self.f_dial.setOrientation(QtCore.Qt.Vertical)
 
-        self.poster_button = but_box.addButton(self.tr("By author"),
+        self.poster_button = but_box.addButton(QtCore.QCoreApplication.translate("ListMyPosts","By author"),
                                      QtGui.QDialogButtonBox.ActionRole)
-        self.date_button = but_box.addButton(self.tr("By date"),
+        self.date_button = but_box.addButton(QtCore.QCoreApplication.translate("ListMyPosts","By date"),
                                        QtGui.QDialogButtonBox.ActionRole)
-        self.read_button = but_box.addButton(self.tr("By read/unread"),
+        self.read_button = but_box.addButton(QtCore.QCoreApplication.translate("ListMyPosts","By read/unread"),
                                      QtGui.QDialogButtonBox.ActionRole)
-        self.text_button = but_box.addButton(self.tr("By content"),
+        self.text_button = but_box.addButton(QtCore.QCoreApplication.translate("ListMyPosts","By content"),
                                       QtGui.QDialogButtonBox.ActionRole)
         self.poster_button.setMinimumWidth(350)
         self.date_button.setMinimumWidth(350)
         self.read_button.setMinimumWidth(350)
         self.text_button.setMinimumWidth(350)
 
-        self.find_in_found = QtGui.QCheckBox(self.tr("Search in results"))
+        self.find_in_found = QtGui.QCheckBox(QtCore.QCoreApplication.translate("ListMyPosts","Search in results"))
         cancel_button = self.f_dial.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
         
@@ -419,15 +428,15 @@ class ListMyPosts(MainWindow):
         handler for choosing filter by poster
         """
         msg = QtGui.QMessageBox()
-        msg.setWindowTitle(self.tr("Filters"))
+        msg.setWindowTitle(QtCore.QCoreApplication.translate("ListMyPosts","Filters"))
     
-        title_label = QtGui.QLabel(self.tr("Choose poster:"), msg)
+        title_label = QtGui.QLabel(QtCore.QCoreApplication.translate("ListMyPosts","Choose poster:"), msg)
         msg.layout().addWidget(title_label, 0, 0)
 
         acc_combo = self.create_combo_filter()
         msg.layout().addWidget(acc_combo, 1, 0)
 
-        ok_button = msg.addButton(self.tr("OK"),
+        ok_button = msg.addButton(QtCore.QCoreApplication.translate("ListMyPosts","OK"),
                                     QtGui.QMessageBox.AcceptRole)
         cancel_button = msg.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
@@ -459,7 +468,7 @@ class ListMyPosts(MainWindow):
         handler for choosing filter by content
         """
         #text contents searching text, ok - result of accepting dialog or ignoring
-        text, ok = QtGui.QInputDialog.getText(self, self.tr("Filters"), self.tr("Search text:"))
+        text, ok = QtGui.QInputDialog.getText(self, QtCore.QCoreApplication.translate("ListMyPosts","Filters"), QtCore.QCoreApplication.translate("ListMyPosts","Search text:"))
         if ok and text:
             first_value = text
             from ldm.Message import TEXT_F
@@ -482,7 +491,7 @@ class ListMyPosts(MainWindow):
         """
         handler for choosing filter by read/unread
         """
-        text, ok = QtGui.QInputDialog.getItem(self, self.tr("Filters"), self.tr("Search text:"),['read','unread'], current = 0, editable = False)
+        text, ok = QtGui.QInputDialog.getItem(self, QtCore.QCoreApplication.translate("ListMyPosts","Filters"), QtCore.QCoreApplication.translate("ListMyPosts","Search text:"),['read','unread'], current = 0, editable = False)
         if ok and text:
             #true = 1, false = 0
             if text == "read":
@@ -509,10 +518,10 @@ class ListMyPosts(MainWindow):
         handler foe choosing filter by date
         """
         msg = QtGui.QMessageBox()
-        msg.setWindowTitle(self.tr("Filters"))
-        title_label = QtGui.QLabel(self.tr("Choose date:"), msg)
-        since_label = QtGui.QLabel(self.tr("Since: "), msg)
-        to_label = QtGui.QLabel(self.tr("To: "), msg)
+        msg.setWindowTitle(QtCore.QCoreApplication.translate("ListMyPosts","Filters"))
+        title_label = QtGui.QLabel(QtCore.QCoreApplication.translate("ListMyPosts","Choose date:"), msg)
+        since_label = QtGui.QLabel(QtCore.QCoreApplication.translate("ListMyPosts","Since: "), msg)
+        to_label = QtGui.QLabel(QtCore.QCoreApplication.translate("ListMyPosts","To: "), msg)
         msg.layout().addWidget(title_label, 0, 0)
         #need two date-time-edit
         date_edit_first = QtGui.QDateTimeEdit(QtCore.QDate.currentDate())
@@ -530,7 +539,7 @@ class ListMyPosts(MainWindow):
         msg.layout().addWidget(date_edit_first, 1, 1)
         msg.layout().addWidget(date_edit_sec, 2, 1)   
 
-        ok_button = msg.addButton(self.tr("OK"),
+        ok_button = msg.addButton(QtCore.QCoreApplication.translate("ListMyPosts","OK"),
                                     QtGui.QMessageBox.AcceptRole)
         cancel_button = msg.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
@@ -545,8 +554,8 @@ class ListMyPosts(MainWindow):
             from ldm.Message import DATE_F
             field = DATE_F
             if first_value > second_value:
-                QtGui.QMessageBox.warning(self, self.tr("Scribo"),
-                               self.tr("Date in first field should be less!"),
+                QtGui.QMessageBox.warning(self, QtCore.QCoreApplication.translate("ListMyPosts","Scribo"),
+                               QtCore.QCoreApplication.translate("ListMyPosts","Date in first field should be less!"),
                                QtGui.QMessageBox.Yes)
                 self.choose_date()
             else:
@@ -636,10 +645,10 @@ class MyProgress(QtGui.QProgressDialog):
         initialization ProgressBar
         """
         QtGui.QProgressDialog.__init__(self, parent)
-        self.setLabelText(self.tr("Operation is in progress."))
-        self.setCancelButtonText(self.tr("Cancel"))
+        self.setLabelText(QtCore.QCoreApplication.translate("MyProgress","Operation is in progress."))
+        self.setCancelButtonText(QtCore.QCoreApplication.translate("MyProgress","Cancel"))
         self.parent = parent
-        self.setWindowTitle(self.tr("Receiving data..."))
+        self.setWindowTitle(QtCore.QCoreApplication.translate("MyProgress","Receiving data..."))
         self.setWindowModality(QtCore.Qt.WindowModal)
         self.value_progress = 1.1
         self.setValue(self.value_progress)
