@@ -47,7 +47,7 @@ class MainWindow(QtGui.QMainWindow):
             ok = font.fromString(str_font)
             if font and ok:
                 self.setFont(font)
-        self.setWindowTitle(self.tr("Scribo"))
+        self.setWindowTitle(QtCore.QCoreApplication.translate("MainWindow","Scribo"))
         self.setMinimumSize(160, 160)
         self.resize(480, 340)
 
@@ -57,8 +57,8 @@ class MainWindow(QtGui.QMainWindow):
             print "no stacked attribute"
         
         self.parent = parent
-        self.new_act = QtGui.QAction(self.tr("&New Account"), self)
-        self.manage_act = QtGui.QAction(self.tr("&Edit Accounts"), self)
+        self.new_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","&New Account"), self)
+        self.manage_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","&Edit Accounts"), self)
         self.create_actions_menu()
         self.create_menus()
         
@@ -89,20 +89,20 @@ class MainWindow(QtGui.QMainWindow):
         @return
         """
         self.dial = QtGui.QMessageBox()
-        self.dial.setWindowTitle(self.tr("Draft"))
+        self.dial.setWindowTitle(QtCore.QCoreApplication.translate("MainWindow","Draft"))
         self.list_drafts = self.view_list_drafts()
         vbox = QtGui.QVBoxLayout()
         but_box = QtGui.QDialogButtonBox()
         but_box.setOrientation(QtCore.Qt.Horizontal)
         
-        self.dial.setWindowTitle(self.tr("Drafts"))
+        self.dial.setWindowTitle(QtCore.QCoreApplication.translate("MainWindow","Drafts"))
         self.dial.setOrientation(QtCore.Qt.Horizontal)
 
-        self.send_button = but_box.addButton(self.tr("Send"),
+        self.send_button = but_box.addButton(QtCore.QCoreApplication.translate("MainWindow","Send"),
                                      QtGui.QDialogButtonBox.ActionRole)
-        self.edit_button = but_box.addButton(self.tr("Edit"),
+        self.edit_button = but_box.addButton(QtCore.QCoreApplication.translate("MainWindow","Edit"),
                                        QtGui.QDialogButtonBox.ActionRole)
-        self.remove_button = but_box.addButton(self.tr("Delete"),
+        self.remove_button = but_box.addButton(QtCore.QCoreApplication.translate("MainWindow","Delete"),
                                        QtGui.QDialogButtonBox.ActionRole)
        
         cancel_button = self.dial.addButton(QtGui.QMessageBox.Abort)
@@ -141,7 +141,7 @@ class MainWindow(QtGui.QMainWindow):
             else:
                date = ""
             if not mes.title:
-                title = unicode(self.tr("no subject"))
+                title = unicode(QtCore.QCoreApplication.translate("MainWindow","no subject"))
             else:
                 title = unicode(mes.title)
             text = date.decode('utf8') + "  " + title
@@ -176,12 +176,12 @@ class MainWindow(QtGui.QMainWindow):
         else:
             self.dial.reject()
             if self.drafts == []:
-                QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("List of drafts is empty!"),
+                QtGui.QMessageBox.information(self, QtCore.QCoreApplication.translate("MainWindow","Scribo"),
+                               QtCore.QCoreApplication.translate("MainWindow","List of drafts is empty!"),
                                QtGui.QMessageBox.Yes)
             else:
-                QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Please, choose messages!"),
+                QtGui.QMessageBox.information(self, QtCore.QCoreApplication.translate("MainWindow","Scribo"),
+                               QtCore.QCoreApplication.translate("MainWindow","Please, choose messages!"),
                                QtGui.QMessageBox.Yes)
             return
         if button == self.send_button:
@@ -211,17 +211,17 @@ class MainWindow(QtGui.QMainWindow):
         """
         from About import __version__ as ver
         self.dial_about = QtGui.QMessageBox(self)
-        self.dial_about.setWindowTitle(self.tr("About Scribo"))
+        self.dial_about.setWindowTitle(QtCore.QCoreApplication.translate("MainWindow","About Scribo"))
         self.dial_about.setIcon(QtGui.QMessageBox.Information)
         
-        label_about =  QtGui.QLabel(self.tr("A mobile multiblog client."\
+        label_about =  QtGui.QLabel(QtCore.QCoreApplication.translate("MainWindow","A mobile multiblog client."\
                                         " \n Version: " + ver+
                                         "\n More information you can get from README file.\n"))  
         #label_about.setBackgroundRole(QtGui.QPalette.AlternateBase)  
         #label_about.setForegroundRole(QtGui.QPalette.Text)
                                    
-        label_friend = QtGui.QLabel(self.tr("You can add us to your friends to leave your feedback"))
-        self.push_fr = QtGui.QPushButton(self.tr("Add friend"), self.dial_about)
+        label_friend = QtGui.QLabel(QtCore.QCoreApplication.translate("MainWindow","You can add us to your friends to leave your feedback"))
+        self.push_fr = QtGui.QPushButton(QtCore.QCoreApplication.translate("MainWindow","Add friend"), self.dial_about)
         self.push_fr.setMinimumWidth(350)
         self.connect(self.push_fr, QtCore.SIGNAL("clicked()"), self.add_us_friend)
         self.dial_about.layout().addWidget(label_about, 0, 0, 1, 2, QtCore.Qt.AlignLeft) 
@@ -246,14 +246,14 @@ class MainWindow(QtGui.QMainWindow):
                 break
         if flag_add_us_fr:
              QtGui.QMessageBox.information(self,
-                              self.tr("Scribo"),
-                              self.tr("Friend is added"),
+                              QtCore.QCoreApplication.translate("MainWindow","Scribo"),
+                              QtCore.QCoreApplication.translate("MainWindow","Friend is added"),
                               QtGui.QMessageBox.Ok)
              self.push_fr.setDisabled(True)
         else:
              QtGui.QMessageBox.warning(self,
-                              self.tr("Scribo"),
-                              self.tr("We wasn't added to the friend. May be, we\
+                              QtCore.QCoreApplication.translate("MainWindow","Scribo"),
+                              QtCore.QCoreApplication.translate("MainWindow","We wasn't added to the friend. May be, we\
                               don't have LiveJournal account, then you can adds it."),
                               QtGui.QMessageBox.Ok)
              
@@ -266,7 +266,7 @@ class MainWindow(QtGui.QMainWindow):
         """
         print type(exc)
         QtGui.QMessageBox.warning(self,
-                                  self.tr("Scribo"),
+                                  QtCore.QCoreApplication.translate("MainWindow","Scribo"),
                                   exc.to_html(),
                                   QtGui.QMessageBox.Ok)
     def settings_change(self):
@@ -276,18 +276,19 @@ class MainWindow(QtGui.QMainWindow):
         @return
         """
         self.dial_set = QtGui.QMessageBox()
-        self.dial_set.setWindowTitle(self.tr("Settings"))
+        self.dial_set.setWindowTitle(QtCore.QCoreApplication.translate("MainWindow","Settings"))
         
         from ConfigDriver import config
         proxy = config.get('Main', 'proxy')
         
-        self.check_proxy = QtGui.QCheckBox(self.tr("Use proxy connections"), self.dial_set)
+        self.check_proxy = QtGui.QCheckBox(QtCore.QCoreApplication.translate("MainWindow","Use proxy connections"), self.dial_set)
         self.check_proxy.adjustSize()
+        self.check_proxy.setMinimumWidth(350)
         self.connect(self.check_proxy, QtCore.SIGNAL("stateChanged (int)"), self.change_set_proxy)
       
-        label_proxy = QtGui.QLabel(self.tr("Proxy: "))
-        label_port = QtGui.QLabel(self.tr("Port: "))
-        label_font = QtGui.QLabel(self.tr("Font: "))
+        label_proxy = QtGui.QLabel(QtCore.QCoreApplication.translate("MainWindow","Proxy: "))
+        label_port = QtGui.QLabel(QtCore.QCoreApplication.translate("MainWindow","Port: "))
+        label_font = QtGui.QLabel(QtCore.QCoreApplication.translate("MainWindow","Font: "))
         
         self.edit_font = QtGui.QLineEdit()
         self.edit_font.setMinimumWidth(500)
@@ -297,7 +298,7 @@ class MainWindow(QtGui.QMainWindow):
             ok = font.fromString(self.font)
             if ok:
                 self.edit_font.setText(self.parse_font(font))
-        self.push_font = QtGui.QPushButton(self.tr("Choose font"), self.dial_set)
+        self.push_font = QtGui.QPushButton(QtCore.QCoreApplication.translate("MainWindow","Choose font"), self.dial_set)
                
         self.edit_proxy = QtGui.QLineEdit()
         self.edit_proxy.setMinimumWidth(350)
@@ -413,17 +414,16 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
-        self.new_act.setShortcut(self.tr("Ctrl+N"))
+        self.new_act.setShortcut(QtCore.QCoreApplication.translate("MainWindow","Ctrl+N"))
         self.connect(self.new_act, QtCore.SIGNAL("triggered()"),
                      self.new_profile)
 
         self.connect(self.manage_act, QtCore.SIGNAL("triggered()"),
                      self.manage_profile)
 
-        self.exit_act = QtGui.QAction(self.tr("E&xit"), self)
-        self.exit_act.setShortcut(self.tr("Ctrl+Q"))
-        self.connect(self.exit_act, QtCore.SIGNAL("triggered()"),
-                     self, QtCore.SLOT("close()"))
+        self.exit_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","E&xit"), self)
+        self.exit_act.setShortcut(QtCore.QCoreApplication.translate("MainWindow","Ctrl+Q"))
+        self.connect(self.exit_act, QtCore.SIGNAL("triggered()"), self.quit_app)
 
         bold_font = self.exit_act.font()
         bold_font.setBold(True)
@@ -432,10 +432,10 @@ class MainWindow(QtGui.QMainWindow):
         self.about_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","About"), self)
         self.connect(self.about_act, QtCore.SIGNAL("triggered()"), self.about)
         
-        self.settings_act = QtGui.QAction(self.tr("Settings"), self)
+        self.settings_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","Settings"), self)
         self.connect(self.settings_act, QtCore.SIGNAL("triggered()"), self.settings_change)
 
-        self.draft_act = QtGui.QAction(self.tr("Drafts"), self)
+        self.draft_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","Drafts"), self)
         self.connect(self.draft_act, QtCore.SIGNAL("triggered()"), self.draft)
 
 
@@ -445,7 +445,7 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
-        self.main_menu = self.menuBar().addMenu(self.tr("&Menu"))
+        self.main_menu = self.menuBar().addMenu(QtCore.QCoreApplication.translate("MainWindow","Menu"))
         self.main_menu.addAction(self.new_act)
         self.main_menu.addAction(self.manage_act)
         self.main_menu.addAction(self.draft_act)
@@ -466,13 +466,27 @@ class MainWindow(QtGui.QMainWindow):
         if self.parent:
             self.parent.show()
         else:
-            ret = QtGui.QMessageBox.question(self, self.tr("Scribo"),
-                                             self.tr("Do you really want to quit?"),
+            ret = QtGui.QMessageBox.question(self, QtCore.QCoreApplication.translate("MainWindow","Scribo"),
+                                             QtCore.QCoreApplication.translate("MainWindow","Do you really want to quit?"),
                                              QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
             if (ret == QtGui.QMessageBox.No):
                 event.ignore()
                 return
-    
+                
+    def quit_app(self):
+        """
+        handler for clicked "back" 
+        @param
+        @return
+        """
+        ret = QtGui.QMessageBox.question(self, QtCore.QCoreApplication.translate("MainWindow","Scribo"),
+                                         QtCore.QCoreApplication.translate("MainWindow","Do you really want to quit?"),
+                                         QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        if (ret == QtGui.QMessageBox.No):
+             return
+        else:
+            QtGui.qApp.quit()
+
     def home_window(self):
         """
         handler for clicked "home"
