@@ -123,6 +123,7 @@ class StartPage(MainWindow):
         username = unicode(self.login_edit.text())
         username = username.lower()
         username = username.replace('-','_')
+        username = username.strip()
         acc = Account.register(service, username)
         acc.passwd = unicode(self.pasw_edit.text())
 
@@ -160,7 +161,7 @@ class StartPage(MainWindow):
         image_label.setAlignment(QtCore.Qt.AlignCenter)
         start_label = QtGui.QLabel(self.tr("<i>Welcome to Scribo,<br/> mobile multiblog client!</i>"), self.centr_widg)
         start_label.setAlignment(QtCore.Qt.AlignCenter)
-        upic = QtGui.QImage(self.tr("../data/Scribo.png"))
+        upic = QtGui.QImage("../data/Scribo.png")
         image_label.setPixmap(QtGui.QPixmap.fromImage(upic))
         vbox1.addWidget(start_label, 0, QtCore.Qt.AlignTop)
         vbox1.addWidget(image_label, 1, QtCore.Qt.AlignCenter)
