@@ -93,7 +93,7 @@ class TreeMessage(MainWindow):
         """
 
         self.refresh_act = QtGui.QToolButton(self.centr_widg)
-        self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
+        self.refresh_act.setIcon(QtGui.QIcon("../data/en/refresh.png"))
         self.refresh_act.setText(self.tr("Refresh"))
         self.refresh_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -101,7 +101,7 @@ class TreeMessage(MainWindow):
                      self.reload_window)
 
         self.decr_act = QtGui.QToolButton(self.centr_widg)
-        self.decr_act.setIcon(QtGui.QIcon(self.tr("../data/en/decrease_font.png")))
+        self.decr_act.setIcon(QtGui.QIcon("../data/en/decrease_font.png"))
         self.decr_act.setText(self.tr("Decrease"))
         self.decr_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.decr_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -109,7 +109,7 @@ class TreeMessage(MainWindow):
                      self.decr_font)
 
         self.incr_act = QtGui.QToolButton(self.centr_widg)
-        self.incr_act.setIcon(QtGui.QIcon(self.tr("../data/en/increase_font.png")))
+        self.incr_act.setIcon(QtGui.QIcon("../data/en/increase_font.png"))
         self.incr_act.setText(self.tr("Increase"))
         self.incr_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.incr_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -149,9 +149,11 @@ class TreeMessage(MainWindow):
         """
         update list messages from database
         """
+        position = self.tree_view.page().mainFrame().scrollPosition()
         comments = self.tree_view.get_post_html(self.msg)
         self.tree_view.setHtml(comments)
         self.tree_view.update()
+        self.tree_view.page().mainFrame().setScrollPosition(position)
 
     def callback(self):
         """
@@ -180,7 +182,6 @@ class ComTree(QWebView):
     class fill tree of comments
     @version  1.0
     @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
-    @todo  what's method's really needed?
      """
     def __init__(self, parent=None, msg=None):
         """ 
@@ -203,6 +204,7 @@ class ComTree(QWebView):
                                                    True)
                                                    
         self.page().setLinkDelegationPolicy(QWebPage.DelegateAllLinks)
+
         #proxy settings
         from ConfigDriver import config
         sett = config.get('Main', 'proxy')
@@ -217,6 +219,7 @@ class ComTree(QWebView):
 
         self.view_mes = msg
         comments_html = self.get_post_html(msg)
+        self.linkClicked.connect(self.link_clicked)
         #print comments_html
         self.setHtml(comments_html, QtCore.QUrl.fromLocalFile("."))
         self.show()
@@ -273,16 +276,16 @@ class ComTree(QWebView):
                           <html xmlns="http://www.w3.org/1999/xhtml">\
                           <head><meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>\
                           <style type="text/css">\
-                          HTML, BODY {padding:0; margin:0; border:0; overflow:hidden; }\
+                          HTML, BODY {padding:0; margin:0; border:0;}\
                           .scribo_stl {%s}\
-                          DIV {min-height: 30px; padding-left: 0px; background-repeat: no-repeat;}\
+                          DIV {min-height: 30px; padding-left: 0px; background-repeat: no-repeat; min-width: 500px;}\
                           div.hide {background-image: url(\'../../data/en/plus.png\');display: block;}\
                           li.scribo { list-style-type: none; }\
-                          .tags {font: 10pt; color: red; text-decoration:underline;}\
-                          .toolbar {font: 10pt \'Times New Roman\';}\
+                          .tags {font: 10pt; color: red; text-decoration:underline; min-width: 300px;}\
+                          .toolbar {font: 10pt \'Times New Roman\'; min-width: 500px;}\
                           .date {font-variant:small-caps; color: #e81f37;left: -12px;}\
-                          .author {font-weight: 600; color: #e81f37; padding: 0px 12px; background: #d7d7d7; max-width: 500px;}\
-                          .title {font: 16pt;}\
+                          .author {font-weight: 600; color: #e81f37; padding: 0px 12px; background: #d7d7d7; min-width: 500px;}\
+                          .title {font: 16pt; min-width: 500px;}\
                           </style>\
                           <script type="text/javascript">\
                           function showHide(id){\
@@ -293,7 +296,7 @@ class ComTree(QWebView):
 			              document.getElementById(id+\'ul\').style.display = \'block\';\
 			              document.getElementById(id).style.backgroundImage = "url(\'../../data/en/plus.png\')";}}\
 			              </script></head><body style="-moz-user-select: none;\
-                                      -khtml-user-select: none; user-select: none;">' %(style_font)
+                                      -khtml-user-select: none; user-select: none;-moz-box-sizing: padding-box;">' %(style_font)
 	
         #fill parent data
         self.comment_html = '<h3><div class="title"><a href = "scribo://%s">%s</a></div></h3>' % (str(msg.id), title)+\
@@ -302,7 +305,6 @@ class ComTree(QWebView):
                             '<div class="scribo_stl"> %s </div>' % (unicode(text))
         
         self.get_html_tree(msg)
-        self.connect(self, QtCore.SIGNAL("linkClicked(const QUrl&)"),self.linkClicked)
         return header_comment+ self.comment_html+'</body></html>'
         
     def get_html_tree(self, msg):
@@ -327,15 +329,30 @@ class ComTree(QWebView):
                 except ValueError:
                     datetime = time.strptime(date, "%Y-%m-%dT%H:%M:%SZ")
                     date = time.strftime("%Y-%m-%d  %H:%M", datetime)
+                style = ""
+                if com.is_frozen():
+                    froze = self.tr("unfreeze")
+                    style = "style = \"background: #d7f6ff;\""
+                else:
+                    froze = self.tr("freeze")
+                    
+                if com.is_screened():
+                    screen = self.tr("unscreen")
+                    style = "style = \"background: #d7f6ff;\""
+                else:
+                    screen = self.tr("screen")
 
 	        if not userpick:
                     userpick = "../../data/en/no_photo_64.png"
                 self.comment_html+='<li class="scribo">'
                 data_comment = '<div class = "author"> <img src="%s" width="32px" height = "32px"/>\
                                %s, %s</div>'%(userpick, unicode(poster.username), date.decode('utf8'))+\
-                               '<div class = "title"><a href = "scribo://%s">%s</a></div>'%(str(com.id), unicode(com.title))+\
-                               '<div class = "scribo_stl">%s</div>'%(unicode(com.text))
-                #'<div class = "toolbar"><a href="scribodel://%s">%s</a></div>'%(str(com.id)," (" + self.tr("Delete") + ") ")
+                               '<div class = "title" %s><a href = "scribo://%s">%s</a></div>'%(style, str(com.id), unicode(com.title))+\
+                               '<div class = "scribo_stl" %s>%s</div>'%(style, unicode(com.text))
+                if not com.is_deleted():
+                    data_comment += '<div class = "toolbar"><a href="scribodel://%s">%s</a> '%(str(com.id)," (" + self.tr("Delete") + ") ")
+                    data_comment +=' <a href="scribofr://%s">%s</a> <a href="scriboscr://%s">%s</a></div>'\
+                                     %(str(com.id)," ("+froze+") ",str(com.id)," ("+screen+") ")
                 if com.comments:
                     self.comment_html+='<div id = "%s" class = "hide" onclick = "showHide(\'%s\')">'%(com.id, com.id)+data_comment+'</div>'
                 else:
@@ -346,18 +363,29 @@ class ComTree(QWebView):
         else:
             return
             
-    def linkClicked(self, url):
+    def link_clicked(self, url):
         """
         overload handler on clicked link
         @param url - url from clicked link
         """
         if url.scheme() == "scribodel":
-            id = url.host()
-            mes = Message(id)
-            owner = mes.journal
-            owner.del_comment(mes)
-            self.parent_window.reload_window()
+            ret = QtGui.QMessageBox.information(self, QtCore.QCoreApplication.translate("TreeMessage","Scribo"),
+                               QtCore.QCoreApplication.translate("TreeMessage","Do you really want to delete comment?"),
+                               QtGui.QMessageBox.Yes,
+                               QtGui.QMessageBox.No)
+            if (ret == QtGui.QMessageBox.No):
+                return
+            else:
+                id = url.host()
+                try:
+                    mes = Message(id)
+                    owner = mes.journal
+                    owner.del_comment(mes)
+                    self.parent_window.reload_window()
+                except:
+                    pass
         elif url.scheme() == "scribo":
+            print "get_next comment"
             id = url.host()
             mes = Message(id)
             if mes.type == COMMENT:
@@ -366,6 +394,23 @@ class ComTree(QWebView):
                 #TO DO get commnets for friends on their accounts
                 list_com = main_prof.get_posts()
             view_widg = ViewMessage(self.parent_window, list_com, mes)
+        elif url.scheme() == "scribofr":
+            print "freezing!!!!"
+            id = url.host()
+            mes = Message(id)
+            #print mes
+            print mes.title
+            owner = mes.journal
+            owner.freeze_comment(mes)
+            self.parent_window.reload_window()
+        elif url.scheme() == "scriboscr":
+            id = url.host()
+            mes = Message(id)
+            #print mes
+            print mes.title
+            owner = mes.journal
+            owner.screen_comment(mes)
+            self.parent_window.reload_window()
         else:
             return
 
