@@ -259,7 +259,7 @@ class ViewMessage(MainWindow):
                      self.refresh_mes)
         """
         self.up_act = QtGui.QToolButton(self.centr_widg)
-        self.up_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_prev.png")))
+        self.up_act.setIcon(QtGui.QIcon("../data/en/post_prev.png"))
         self.up_act.setText(self.tr("Previous"))
         self.up_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.up_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)        
@@ -267,7 +267,7 @@ class ViewMessage(MainWindow):
                      self.view_prev_message)
 
         self.down_act = QtGui.QToolButton(self.centr_widg)
-        self.down_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_next.png")))
+        self.down_act.setIcon(QtGui.QIcon("../data/en/post_next.png"))
         self.down_act.setText(self.tr("Next"))
         self.down_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.down_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -275,7 +275,7 @@ class ViewMessage(MainWindow):
                      self.view_next_message)
         
         self.decr_act = QtGui.QToolButton(self.centr_widg)
-        self.decr_act.setIcon(QtGui.QIcon(self.tr("../data/en/decrease_font.png")))
+        self.decr_act.setIcon(QtGui.QIcon("../data/en/decrease_font.png"))
         self.decr_act.setText(self.tr("Decrease"))
         self.decr_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.decr_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -283,7 +283,7 @@ class ViewMessage(MainWindow):
                      self.decr_font)
 
         self.incr_act = QtGui.QToolButton(self.centr_widg)
-        self.incr_act.setIcon(QtGui.QIcon(self.tr("../data/en/increase_font.png")))
+        self.incr_act.setIcon(QtGui.QIcon("../data/en/increase_font.png"))
         self.incr_act.setText(self.tr("Increase"))
         self.incr_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.incr_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -299,7 +299,7 @@ class ViewMessage(MainWindow):
                      self.write_comment)
         
         self.edit_act = QtGui.QToolButton(self.centr_widg)
-        self.edit_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_edit.png")))
+        self.edit_act.setIcon(QtGui.QIcon("../data/en/post_edit.png"))
         self.edit_act.setText(self.tr("Edit"))
         self.edit_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.edit_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
